@@ -5,15 +5,16 @@ from collections import OrderedDict
 from itertools import islice
 
 from django.utils import six
+from django.utils.safestring import SafeData
 
 from django_tables2.templatetags.django_tables2 import title
-from django_tables2.utils import Accessor, AttributeDict, OrderBy, OrderByTuple
+from django_tables2.utils import Accessor, AttributeDict, OrderBy, OrderByTuple, call_with_appropriate, computed_values
 
 
 class Library(object):
-    """
+    '''
     A collection of columns.
-    """
+    '''
     def __init__(self):
         self.columns = []
 
@@ -22,11 +23,12 @@ class Library(object):
         return column
 
     def column_for_field(self, field):
-        """
+        '''
         Return a column object suitable for model field.
 
-        :returns: column object of `None`
-        """
+        Returns:
+            `.Column` object or `None`
+        '''
         # iterate in reverse order as columns are registered in order
         # of least to most specialised (i.e. Column is registered
         # first). This also allows user-registered columns to be
@@ -48,102 +50,68 @@ library = Library()
 
 @library.register
 class Column(object):
-    """
+    '''
     Represents a single column of a table.
 
-    `.Column` objects control the way a column (including the cells that
-    fall within it) are rendered.
+    `.Column` objects control the way a column (including the cells that fall
+    within it) are rendered.
+
+    Arguments:
+        attrs (dict): HTML attributes for elements that make up the column.
+            This API is extended by subclasses to allow arbitrary HTML
+            attributes to be added to the output.
+
+            By default `.Column` supports:
+
+             - *th* -- ``table/thead/tr/th`` elements
+             - *td* -- ``table/tbody/tr/td`` elements
+             - *cell* -- fallback if *th* or *td* isn't defined
+        accessor (str or `~.Accessor`): An accessor that describes how to
+            extract values for this column from the :term:`table data`.
+        default (str or callable): The default value for the column. This can be
+            a value or a callable object [1]_. If an object in the data provides
+            `None` for a column, the default will be used instead.
+
+            The default value may affect ordering, depending on the type of data
+            the table is using. The only case where ordering is not affected is
+            when a `.QuerySet` is used as the table data (since sorting is
+            performed by the database).
+        empty_values (iterable): list of values considered as a missing value,
+            for which the column will render the default value. Defaults to
+            `(None, '')`
+        exclude_from_export (bool): If `True`, this column will not be added to
+            the data iterator returned from as_values().
+        footer (str, callable): Defines the footer of this column. If a callable
+            is passed, it can take optional keyword argumetns `column`,
+            `bound_colun` and `table`.
+        order_by (str, tuple or `.Accessor`): Allows one or more accessors to be
+            used for ordering rather than *accessor*.
+        orderable (bool): If `False`, this column will not be allowed to
+            influence row ordering/sorting.
+        verbose_name (str): A human readable version of the column name.
+        visible (bool): If `True`, this column will be rendered.
+        localize: If the cells in this column will be localized by the
+            `localize` filter:
+
+              - If `True`, force localization
+              - If `False`, values are not localized
+              - If `None` (default), localization depends on the ``USE_L10N`` setting.
 
 
-    .. attribute:: attrs
-
-        HTML attributes for elements that make up the column.
-
-        :type: `dict`
-
-        This API is extended by subclasses to allow arbitrary HTML attributes
-        to be added to the output.
-
-        By default `.Column` supports:
-
-        - *th* -- ``table/thead/th`` elements
-        - *td* -- ``table/tbody/tr/td`` elements
-        - *cell* -- fallback if *th* or *td* isn't defined
-
-
-    .. attribute:: accessor
-
-        An accessor that describes how to extract values for this column from
-        the :term:`table data`.
-
-        :type: string or `~.Accessor`
-
-
-    .. attribute:: default
-
-        The default value for the column. This can be a value or a callable
-        object [1]_. If an object in the data provides `None` for a column, the
-        default will be used instead.
-
-        The default value may affect ordering, depending on the type of data
-        the table is using. The only case where ordering is not affected is
-        when a `.QuerySet` is used as the table data (since sorting is
-        performed by the database).
-
-        .. [1] The provided callable object must not expect to receive any
-               arguments.
-
-
-    .. attribute:: order_by
-
-        Allows one or more accessors to be used for ordering rather than
-        *accessor*.
-
-        :type: `unicode`, `tuple`, `~.Accessor`
-
-
-    .. attribute:: orderable
-
-        If `False`, this column will not be allowed to influence row
-        ordering/sorting.
-
-        :type: `bool`
-
-
-    .. attribute:: verbose_name
-
-        A human readable version of the column name.
-
-        :type: `unicode`
-
-
-    .. attribute:: visible
-
-        If `True`, this column will be included in the HTML output.
-
-        :type: `bool`
-
-
-    .. attribute:: localize
-
-        *   If `True`, cells of this column will be localized in the HTML output
-            by the localize filter.
-
-        *   If `False`, cells of this column will be unlocalized in the HTML output
-            by the unlocalize filter.
-
-        *   If `None` (the default), cell will be rendered as is and localization will depend
-            on ``USE_L10N`` setting.
-
-        :type: `bool`
-    """
-    #: Tracks each time a Column instance is created. Used to retain order.
+    .. [1] The provided callable object must not expect to receive any arguments.
+    '''
+    # Tracks each time a Column instance is created. Used to retain order.
     creation_counter = 0
     empty_values = (None, '')
 
+    # Explicit is set to True if the column is defined as an attribute of a
+    # class, used to give explicit columns precedence.
+    _explicit = False
+
     def __init__(self, verbose_name=None, accessor=None, default=None,
                  visible=True, orderable=None, attrs=None, order_by=None,
-                 empty_values=None, localize=None):
+                 empty_values=None, localize=None, footer=None,
+                 exclude_from_export=False):
         if not (accessor is None or isinstance(accessor, six.string_types) or
                 callable(accessor)):
             raise TypeError('accessor must be a string or callable, not %s' %
@@ -167,6 +135,10 @@ class Column(object):
         self.creation_counter = Column.creation_counter
         Column.creation_counter += 1
 
+        self._footer = footer
+
+        self.exclude_from_export = exclude_from_export
+
     @property
     def default(self):
         # handle callables
@@ -174,7 +146,7 @@ class Column(object):
 
     @property
     def header(self):
-        """
+        '''
         The value used for the column heading (e.g. inside the ``<th>`` tag).
 
         By default this returns `~.Column.verbose_name`.
@@ -189,40 +161,90 @@ class Column(object):
             column name (it's only available on a `.BoundColumn` object hence
             accessing that first) when this property doesn't return something
             useful.
-        """
+        '''
         return self.verbose_name
 
+    def footer(self, bound_column, table):
+        '''
+        Returns the content of the footer, if specified.
+        '''
+        footer_kwargs = {
+            'column': self,
+            'bound_column': bound_column,
+            'table': table
+        }
+
+        if self._footer is not None:
+            if callable(self._footer):
+                return call_with_appropriate(self._footer, footer_kwargs)
+            else:
+                return self._footer
+
+        if hasattr(self, 'render_footer'):
+            return call_with_appropriate(self.render_footer, footer_kwargs)
+
+        return ''
+
     def render(self, value):
-        """
+        '''
         Returns the content for a specific cell.
 
         This method can be overridden by :ref:`table.render_FOO` methods on the
         table or by subclassing `.Column`.
 
-        :returns: `unicode`
-
         If the value for this cell is in `.empty_values`, this method is
         skipped and an appropriate default value is rendered instead.
         Subclasses should set `.empty_values` to ``()`` if they want to handle
         all values in `.render`.
-        """
+        '''
         return value
 
+    def value(self, **kwargs):
+        '''
+        Returns the content for a specific cell similarly to `.render` however
+        without any html content. This can be used to get the data in the
+        formatted as it is presented but in a form that could be added to a csv
+        file.
+
+        The default implementation just calls the `render` function but any
+        subclasses where `render` returns html content should override this
+        method.
+
+        See `LinkColumn` for an example.
+        '''
+        value = call_with_appropriate(self.render, kwargs)
+
+        return value
+
+    def order(self, queryset, is_descending):
+        '''
+        Returns the queryset of the table.
+
+        This method can be overridden by :ref:`table.order_FOO` methods on the
+        table or by subclassing `.Column`; but only overrides if second element
+        in return tuple is True.
+
+        returns:
+            Tuple (queryset, boolean)
+        '''
+        return (queryset, False)
+
     @classmethod
     def from_field(cls, field):
-        """
+        '''
         Return a specialised column for the model field or `None`.
 
-        :param field: the field that needs a suitable column
-        :type  field: model field instance
-        :returns: `.Column` object or `None`
+        Arguments:
+            field (Model Field instance): the field that needs a suitable column
+        Returns:
+            `.Column` object or `None`
 
         If the column isn't specialised for the given model field, it should
         return `None`. This gives other columns the opportunity to do better.
 
         If the column is specialised, it should return an instance of itself
         that's configured appropriately for the field.
-        """
+        '''
         # Since this method is inherited by every subclass, only provide a
         # column if this class was asked directly.
         if cls is Column:
@@ -230,36 +252,32 @@ class Column(object):
                 verbose_name = field.get_related_field().verbose_name
             else:
                 verbose_name = getattr(field, 'verbose_name', field.name)
-            return cls(verbose_name=verbose_name)
+            return cls(verbose_name=title(verbose_name))
 
 
 @six.python_2_unicode_compatible
 class BoundColumn(object):
-    """
+    '''
     A *run-time* version of `.Column`. The difference between
     `.BoundColumn` and `.Column`, is that `.BoundColumn` objects include the
     relationship between a `.Column` and a `.Table`. In practice, this
     means that a `.BoundColumn` knows the *"variable name"* given to the
     `.Column` when it was declared on the `.Table`.
 
-    For convenience, all `.Column` properties are available from thisclass.
+    For convenience, all `.Column` properties are available from this class.
 
-    :type   table: `.Table` object
-    :param  table: the table in which this column exists
-    :type  column: `.Column` object
-    :param column: the type of column
-    :type    name: string object
-    :param   name: the variable name of the column used to when defining the
-                   `.Table`. In this example the name is ``age``:
+    arguments:
+        table (`~.Table`): The table in which this column exists
+        column (`~.Column`): The type of column
+        name (str): The variable name of the column used when defining the
+                    `.Table`. In this example the name is ``age``::
 
-                       .. code-block:: python
+                          class SimpleTable(tables.Table):
+                              age = tables.Column()
 
-                           class SimpleTable(tables.Table):
-                               age = tables.Column()
-
-    """
+    '''
     def __init__(self, table, column, name):
-        self.table = table
+        self._table = table
         self.column = column
         self.name = name
 
@@ -268,62 +286,88 @@ class BoundColumn(object):
 
     @property
     def accessor(self):
-        """
+        '''
         Returns the string used to access data for this column out of the data
         source.
-        """
+        '''
         return self.column.accessor or Accessor(self.name)
 
     @property
     def attrs(self):
-        """
+        '''
         Proxy to `.Column.attrs` but injects some values of our own.
 
         A ``th`` and ``td`` are guaranteed to be defined (irrespective of
         what's actually defined in the column attrs. This makes writing
         templates easier.
-        """
-        # Work on a copy of the attrs object since we're tweaking stuff
-        attrs = dict(self.column.attrs)
+        '''
+        # Start with table's attrs; Only 'th' and 'td' attributes will be used
+        attrs = dict(self._table.attrs)
 
-        # Find the relevant th attributes (fall back to cell if th isn't
-        # explicitly specified).
-        attrs['th'] = AttributeDict(attrs.get('th', attrs.get('cell', {})))
-        attrs['td'] = AttributeDict(attrs.get('td', attrs.get('cell', {})))
+        # Update attrs to prefer column's attrs rather than table's
+        attrs.update(dict(self.column.attrs))
 
-        # make set of existing classes.
-        th_class = set((c for c in attrs['th'].get('class', '').split(' ') if c))
-        td_class = set((c for c in attrs['td'].get('class', '').split(' ') if c))
+        # we take the value for 'cell' as the basis for both the th and td attrs
+        cell_attrs = attrs.get('cell', {})
+        # override with attrs defined specifically for th and td respectively.
+        kwargs = {
+            'table': self._table,
+            'column': self
+        }
+        attrs['th'] = computed_values(attrs.get('th', cell_attrs), kwargs=kwargs)
+        attrs['td'] = computed_values(attrs.get('td', cell_attrs), kwargs=kwargs)
+
+        # wrap in AttributeDict
+        attrs['th'] = AttributeDict(attrs['th'])
+        attrs['td'] = AttributeDict(attrs['td'])
+
+        # Override/add classes
+        attrs['th']['class'] = self.get_th_class(attrs['th'])
+        attrs['td']['class'] = self.get_td_class(attrs['td'])
+
+        return attrs
+
+    def get_td_class(self, td_attrs):
+        '''
+        Returns the HTML class attribute for a data cell in this column
+        '''
+        classes = set((c for c in td_attrs.get('class', '').split(' ') if c))
+        classes = self._table.get_column_class_names(classes, self)
+        return ' '.join(sorted(classes))
+
+    def get_th_class(self, th_attrs):
+        '''
+        Returns the HTML class attribute for a header cell in this column
+        '''
+        classes = set((c for c in th_attrs.get('class', '').split(' ') if c))
+        classes = self._table.get_column_class_names(classes, self)
 
         # add classes for ordering
+        ordering_class = th_attrs.get('_ordering', {})
         if self.orderable:
-            th_class.add('orderable')
+            classes.add(ordering_class.get('orderable', 'orderable'))
         if self.is_ordered:
-            th_class.add('desc' if self.order_by_alias.is_descending else 'asc')
+            classes.add(ordering_class.get('descending', 'desc')
+                        if self.order_by_alias.is_descending
+                        else ordering_class.get('ascending', 'asc'))
 
-        # Always add the column name as a class
-        th_class.add(self.name)
-        td_class.add(self.name)
-
-        attrs['th']['class'] = ' '.join(sorted(th_class))
-        attrs['td']['class'] = ' '.join(sorted(td_class))
-        return attrs
+        return ' '.join(sorted(classes))
 
     @property
     def default(self):
-        """
+        '''
         Returns the default value for this column.
-        """
+        '''
         value = self.column.default
         if value is None:
-            value = self.table.default
+            value = self._table.default
         return value
 
     @property
     def header(self):
-        """
+        '''
         The value that should be used in the header cell for this column.
-        """
+        '''
         # favour Column.header
         column_header = self.column.header
         if column_header:
@@ -331,14 +375,24 @@ class BoundColumn(object):
         # fall back to automatic best guess
         return self.verbose_name
 
+    @property
+    def footer(self):
+        return call_with_appropriate(self.column.footer, {
+            'bound_column': self,
+            'table': self._table
+        })
+
+    def has_footer(self):
+        return self.column._footer is not None or hasattr(self.column, 'render_footer')
+
     @property
     def order_by(self):
-        """
+        '''
         Returns an `.OrderByTuple` of appropriately prefixed data source
         keys used to sort this column.
 
         See `.order_by_alias` for details.
-        """
+        '''
         if self.column.order_by is not None:
             order_by = self.column.order_by
         else:
@@ -348,7 +402,7 @@ class BoundColumn(object):
 
     @property
     def order_by_alias(self):
-        """
+        '''
         Returns an `OrderBy` describing the current state of ordering for this
         column.
 
@@ -372,13 +426,13 @@ class BoundColumn(object):
         e.g.::
 
             >>> class SimpleTable(tables.Table):
-            ...     name = tables.Column(order_by=("firstname", "last_name"))
+            ...     name = tables.Column(order_by=('firstname', 'last_name'))
             ...
-            >>> table = SimpleTable([], order_by=("-name", ))
-            >>> table.columns["name"].order_by_alias
-            "-name"
-            >>> table.columns["name"].order_by
-            ("-first_name", "-last_name")
+            >>> table = SimpleTable([], order_by=('-name', ))
+            >>> table.columns['name'].order_by_alias
+            '-name'
+            >>> table.columns['name'].order_by
+            ('-first_name', '-last_name')
 
         The `OrderBy` returned has been patched to include an extra attribute
         ``next``, which returns a version of the alias that would be
@@ -388,7 +442,7 @@ class BoundColumn(object):
             ascending  -> descending
             descending -> ascending
 
-        This is useful otherwise in templates you'd need something like:
+        This is useful otherwise in templates you'd need something like::
 
             {% if column.is_ordered %}
             {% querystring table.prefixed_order_by_field=column.order_by_alias.opposite %}
@@ -396,60 +450,74 @@ class BoundColumn(object):
             {% querystring table.prefixed_order_by_field=column.order_by_alias %}
             {% endif %}
 
-        """
-        order_by = OrderBy((self.table.order_by or {}).get(self.name, self.name))
+        '''
+        order_by = OrderBy((self._table.order_by or {}).get(self.name, self.name))
         order_by.next = order_by.opposite if self.is_ordered else order_by
         return order_by
 
     @property
     def is_ordered(self):
-        return self.name in (self.table.order_by or ())
+        return self.name in (self._table.order_by or ())
 
     @property
     def orderable(self):
-        """
+        '''
         Return a `bool` depending on whether this column supports ordering.
-        """
+        '''
         if self.column.orderable is not None:
             return self.column.orderable
-        return self.table.orderable
+        return self._table.orderable
 
     @property
     def verbose_name(self):
-        """
-        Return the verbose name for this column, or fallback to the titlised
-        column name.
+        '''
+        Return the verbose name for this column.
+
+        In order of preference, this will return:
+          1) The column's explicitly defined `verbose_name`
+          2) The titlised model's `verbose_name` (if applicable)
+          3) Fallback to the titlised column name.
+
+        Any `verbose_name` that was not passed explicitly in the column
+        definition is returned titlised in keeping with the Django convention
+        of `verbose_name` being defined in lowercase and uppercased/titlised
+        as needed by the application.
 
         If the table is using queryset data, then use the corresponding model
         field's `~.db.Field.verbose_name`. If it's traversing a relationship,
         then get the last field in the accessor (i.e. stop when the
         relationship turns from ORM relationships to object attributes [e.g.
         person.upper should stop at person]).
-        """
+        '''
         # Favor an explicit defined verbose_name
         if self.column.verbose_name is not None:
             return self.column.verbose_name
 
         # This is our reasonable fallback, should the next section not result
         # in anything useful.
-        name = title(self.name.replace('_', ' '))
+        name = self.name.replace('_', ' ')
 
         # Try to use a model field's verbose_name
-        if hasattr(self.table.data, 'queryset') and hasattr(self.table.data.queryset, 'model'):
-            model = self.table.data.queryset.model
+        model = self._table.data.get_model()
+        if model:
             field = Accessor(self.accessor).get_field(model)
             if field:
                 if hasattr(field, 'field'):
                     name = field.field.verbose_name
                 else:
                     name = getattr(field, 'verbose_name', field.name)
-        return name
+
+            # If verbose_name was mark_safe()'d, return intact to keep safety
+            if isinstance(name, SafeData):
+                return name
+
+        return title(name)
 
     @property
     def visible(self):
-        """
+        '''
         Returns a `bool` depending on whether this column is visible.
-        """
+        '''
         return self.column.visible
 
     @property
@@ -461,7 +529,7 @@ class BoundColumn(object):
 
 
 class BoundColumns(object):
-    """
+    '''
     Container for spawning `.BoundColumn` objects.
 
     This is bound to a table and provides its `.Table.columns` property.
@@ -477,15 +545,18 @@ class BoundColumns(object):
     At the moment you'll only come across this class when you access a
     `.Table.columns` property.
 
-    :type  table: `.Table` object
-    :param table: the table containing the columns
-    """
-    def __init__(self, table):
-        self.table = table
+    Arguments:
+        table (`.Table`): the table containing the columns
+    '''
+    def __init__(self, table, base_columns):
+        self._table = table
         self.columns = OrderedDict()
-        for name, column in six.iteritems(table.base_columns):
+        for name, column in six.iteritems(base_columns):
             self.columns[name] = bc = BoundColumn(table, column, name)
             bc.render = getattr(table, 'render_' + name, column.render)
+            # How the value is defined: 1. value_<name> 2. render_<name> 3. column.value.
+            bc.value = getattr(table, 'value_' + name, getattr(table, 'render_' + name, column.value))
+            bc.order = getattr(table, 'order_' + name, column.order)
 
     def iternames(self):
         return (name for name, column in self.iteritems())
@@ -494,69 +565,88 @@ class BoundColumns(object):
         return list(self.iternames())
 
     def iterall(self):
-        """
+        '''
         Return an iterator that exposes all `.BoundColumn` objects,
         regardless of visiblity or sortability.
-        """
+        '''
         return (column for name, column in self.iteritems())
 
     def all(self):
         return list(self.iterall())
 
     def iteritems(self):
-        """
+        '''
         Return an iterator of ``(name, column)`` pairs (where ``column`` is a
         `BoundColumn`).
 
         This method is the mechanism for retrieving columns that takes into
         consideration all of the ordering and filtering modifiers that a table
         supports (e.g. `~Table.Meta.exclude` and `~Table.Meta.sequence`).
-        """
-        for name in self.table.sequence:
-            if name not in self.table.exclude:
+        '''
+
+        for name in self._table.sequence:
+            if name not in self._table.exclude:
                 yield (name, self.columns[name])
 
     def items(self):
         return list(self.iteritems())
 
     def iterorderable(self):
-        """
+        '''
         Same as `BoundColumns.all` but only returns orderable columns.
 
         This is useful in templates, where iterating over the full
         set and checking ``{% if column.ordarable %}`` can be problematic in
         conjunction with e.g. ``{{ forloop.last }}`` (the last column might not
         be the actual last that is rendered).
-        """
+        '''
         return (x for x in self.iterall() if x.orderable)
 
     def orderable(self):
         return list(self.iterorderable())
 
     def itervisible(self):
-        """
+        '''
         Same as `.iterorderable` but only returns visible `.BoundColumn`
         objects.
 
         This is geared towards table rendering.
-        """
+        '''
         return (x for x in self.iterall() if x.visible)
 
     def visible(self):
         return list(self.itervisible())
 
+    def hide(self, name):
+        '''
+        Hide a column.
+
+        Arguments:
+            name(str): name of the column
+        '''
+        self.columns[name].column.visible = False
+
+    def show(self, name):
+        '''
+        Show a column otherwise hidden.
+
+        Arguments:
+            name(str): name of the column
+        '''
+        self.columns[name].column.visible = True
+
     def __iter__(self):
-        """
+        '''
         Convenience API, alias of `.itervisible`.
-        """
+        '''
         return self.itervisible()
 
     def __contains__(self, item):
-        """
+        '''
         Check if a column is contained within a `Columns` object.
 
-        *item* can either be a `BoundColumn` object, or the name of a column.
-        """
+        *item* can either be a `~.BoundColumn` object, or the name of a column.
+        '''
         if isinstance(item, six.string_types):
             return item in self.iternames()
         else:
@@ -564,15 +654,15 @@ class BoundColumns(object):
             return item in self.iterall()
 
     def __len__(self):
-        """
-        Return how many :class:`BoundColumn` objects are contained (and
+        '''
+        Return how many `~.BoundColumn` objects are contained (and
         visible).
-        """
+        '''
         return len(self.visible())
 
     def __getitem__(self, index):
-        """
-        Retrieve a specific `BoundColumn` object.
+        '''
+        Retrieve a specific `~.BoundColumn` object.
 
         *index* can either be 0-indexed or the name of a column
 
@@ -580,7 +670,7 @@ class BoundColumns(object):
 
             columns['speed']  # returns a bound column with name 'speed'
             columns[0]        # returns the first column
-        """
+        '''
         if isinstance(index, int):
             try:
                 return next(islice(self.iterall(), index, index + 1))
