@@ -3,22 +3,23 @@ from __future__ import absolute_import, unicode_literals
 
 from django.db import models
 
+from django_tables2.templatetags.django_tables2 import title
+
 from .base import library
 from .templatecolumn import TemplateColumn
 
 
 @library.register
 class DateColumn(TemplateColumn):
-    """
+    '''
     A column that renders dates in the local timezone.
 
-    :param format: format string in same format as Django's ``date`` template
-                   filter (optional)
-    :type  format: `unicode`
-    :param  short: if *format* is not specified, use Django's
-                   ``SHORT_DATE_FORMAT`` setting, otherwise use ``DATE_FORMAT``
-    :type   short: `bool`
-    """
+    Arguments:
+        format (str): format string in same format as Django's ``date`` template
+                      filter (optional)
+        short (bool): if `format` is not specified, use Django's
+                      ``SHORT_DATE_FORMAT`` setting, otherwise use ``DATE_FORMAT``
+    '''
     def __init__(self, format=None, short=True, *args, **kwargs):
         if format is None:
             format = 'SHORT_DATE_FORMAT' if short else 'DATE_FORMAT'
@@ -28,4 +29,4 @@ class DateColumn(TemplateColumn):
     @classmethod
     def from_field(cls, field):
         if isinstance(field, models.DateField):
-            return cls(verbose_name=field.verbose_name)
+            return cls(verbose_name=title(field.verbose_name))
