@@ -4,20 +4,23 @@ from __future__ import absolute_import, unicode_literals
 from django.conf import settings
 from django.db import models
 
+from django_tables2.templatetags.django_tables2 import title
+
 from .base import library
 from .templatecolumn import TemplateColumn
 
 
 @library.register
 class TimeColumn(TemplateColumn):
-    """
+    '''
     A column that renders times in the local timezone.
 
-    :param format: format string in same format as Django's ``time`` template
-                   filter (optional)
-    :type  format: `unicode`
-    :param  short: if *format* is not specified, use Django's ``TIME_FORMAT`` setting
-    """
+    Arguments:
+        format (str): format string in same format as Django's ``time`` template
+            filter (optional)
+        short (bool): if *format* is not specified, use Django's ``TIME_FORMAT``
+            setting
+    '''
     def __init__(self, format=None, *args, **kwargs):
         if format is None:
             format = settings.TIME_FORMAT
@@ -27,4 +30,4 @@ class TimeColumn(TemplateColumn):
     @classmethod
     def from_field(cls, field):
         if isinstance(field, models.TimeField):
-            return cls(verbose_name=field.verbose_name)
+            return cls(verbose_name=title(field.verbose_name))
