@@ -3,19 +3,21 @@ from __future__ import absolute_import, unicode_literals
 
 from django.db import models
 
+from django_tables2.templatetags.django_tables2 import title
+
 from .base import library
 from .linkcolumn import BaseLinkColumn
 
 
 @library.register
 class URLColumn(BaseLinkColumn):
-    """
+    '''
     Renders URL values as hyperlinks.
 
-    :param text: Either static text, or a callable. If set, this
-                 value will be used to render the text inside link
-                 instead of value (default)
-    :param attrs: Additional attributes for the ``<a>`` tag
+    Arguments:
+        text (str or callable): Either static text, or a callable. If set, this
+            will be used to render the text inside link instead of value (default)
+        attrs (dict): Additional attributes for the ``<a>`` tag
 
     Example::
 
@@ -24,13 +26,12 @@ class URLColumn(BaseLinkColumn):
         ...
         >>> table = CompaniesTable([{'www': 'http://google.com'}])
         >>> table.rows[0].get_cell('www')
-        u'<a href="http://google.com">http://google.com</a>'
-
-    """
+        '<a href="http://google.com">http://google.com</a>'
+    '''
     def render(self, record, value):
         return self.render_link(value, record=record, value=value)
 
     @classmethod
     def from_field(cls, field):
         if isinstance(field, models.URLField):
-            return cls(verbose_name=field.verbose_name)
+            return cls(verbose_name=title(field.verbose_name))
