@@ -21,21 +21,21 @@ from django_tables2.config import RequestConfig
 register = template.Library()
 kwarg_re = re.compile(r"(?:(.+)=)?(.+)")
 context_processor_error_msg = (
-    "Tat {%% %s %%} requires django.template.context_processors.request to be "
-    "in the template configuration in "
-    "settings.TEMPLATES[]OPTIONS.context_processors) in order for the included "
-    "template tags to function correctly."
+    'Tag {%% %s %%} requires django.template.context_processors.request to be '
+    'in the template configuration in '
+    'settings.TEMPLATES[]OPTIONS.context_processors) in order for the included '
+    'template tags to function correctly.'
 )
 
 
 def token_kwargs(bits, parser):
-    """
+    '''
     Based on Django's `~django.template.defaulttags.token_kwargs`, but with a
     few changes:
 
     - No legacy mode.
     - Both keys and values are compiled as a filter
-    """
+    '''
     if not bits:
         return {}
     kwargs = OrderedDict()
@@ -63,17 +63,17 @@ class QuerystringNode(Node):
         for key, value in self.updates.items():
             key = key.resolve(context)
             value = value.resolve(context)
-            if key not in ("", None):
+            if key not in ('', None):
                 params[key] = value
         for removal in self.removals:
             params.pop(removal.resolve(context), None)
-        return escape("?" + urlencode(params, doseq=True))
+        return escape('?' + urlencode(params, doseq=True))
 
 
 # {% querystring "name"="abc" "age"=15 %}
 @register.tag
 def querystring(parser, token):
-    """
+    '''
     Creates a URL (containing only the querystring [including "?"]) derived
     from the current URL's querystring, by updating it with the provided
     keyword arguments.
@@ -85,25 +85,24 @@ def querystring(parser, token):
         {% querystring "name"="Ayers" without "gender" %}
         ?name=Ayers
 
-    """
+    '''
     bits = token.split_contents()
     tag = bits.pop(0)
     updates = token_kwargs(bits, parser)
     # ``bits`` should now be empty of a=b pairs, it should either be empty, or
     # have ``without`` arguments.
-    if bits and bits.pop(0) != "without":
+    if bits and bits.pop(0) != 'without':
         raise TemplateSyntaxError("Malformed arguments to '%s'" % tag)
     removals = [parser.compile_filter(bit) for bit in bits]
     return QuerystringNode(updates, removals)
 
 
 class RenderTableNode(Node):
-    """
-    :param    table: the table to render
-    :type     table: Table object
-    :param template: Name[s] of template to render
-    :type  template: unicode or list
-    """
+    '''
+    parameters:
+        table (~.Table): the table to render
+        template (str or list): Name[s] of template to render
+    '''
     def __init__(self, table, template=None):
         super(RenderTableNode, self).__init__()
         self.table = table
@@ -112,9 +111,11 @@ class RenderTableNode(Node):
     def render(self, context):
         table = self.table.resolve(context)
 
-        if isinstance(table, tables.Table):
+        request = context.get('request')
+
+        if isinstance(table, tables.TableBase):
             pass
-        elif hasattr(table, "model"):
+        elif hasattr(table, 'model'):
             queryset = table
 
             # We've been given a queryset, create a table using its model and
@@ -122,14 +123,13 @@ class RenderTableNode(Node):
             class OnTheFlyTable(tables.Table):
                 class Meta:
                     model = queryset.model
-                    attrs = {"class": "paleblue"}
+
             table = OnTheFlyTable(queryset)
-            request = context.get('request')
             if request:
                 RequestConfig(request).configure(table)
         else:
-            raise ValueError("Expected table or queryset, not '%s'." %
-                             type(table).__name__)
+            klass = type(table).__name__
+            raise ValueError('Expected table or queryset, not {}'.format(klass))
 
         if self.template:
             template = self.template.resolve(context)
@@ -145,7 +145,7 @@ class RenderTableNode(Node):
         # Contexts are basically a `MergeDict`, when you `update()`, it
         # internally just adds a dict to the list to attempt lookups from. This
         # is why we're able to `pop()` later.
-        context.update({"table": table})
+        context.update({'table': table})
         try:
             # HACK:
             # TemplateColumn benefits from being able to use the context
@@ -153,6 +153,7 @@ class RenderTableNode(Node):
             # achieved is to temporarily attach the context to the table,
             # which TemplateColumn then looks for and uses.
             table.context = context
+            table.before_render(request)
             return template.render(context.flatten())
         finally:
             del table.context
@@ -161,7 +162,7 @@ class RenderTableNode(Node):
 
 @register.tag
 def render_table(parser, token):
-    """
+    '''
     Render a HTML table.
 
     The tag can be given either a `.Table` object, or a queryset. An optional
@@ -179,7 +180,7 @@ def render_table(parser, token):
         class OnTheFlyTable(tables.Table):
             class Meta:
                 model = queryset.model
-                attrs = {"class": "paleblue"}
+                attrs = {'class': 'paleblue'}
 
     For configuration beyond this, a `.Table` class must be manually defined,
     instantiated, and passed to this tag.
@@ -187,34 +188,43 @@ def render_table(parser, token):
     The context should include a *request* variable containing the current
     request. This allows pagination URLs to be created without clobbering the
     existing querystring.
-    """
+    '''
     bits = token.split_contents()
-    try:
-        bits.pop(0)
-        table = parser.compile_filter(bits.pop(0))
-    except ValueError:
-        raise TemplateSyntaxError("'%s' must be given a table or queryset." % bits[0])
+    bits.pop(0)
 
+    table = parser.compile_filter(bits.pop(0))
     template = parser.compile_filter(bits.pop(0)) if bits else None
+
     return RenderTableNode(table, template)
 
 
-RE_UPPERCASE = re.compile('[A-Z]')
-
-
 @register.filter
 @stringfilter
 def title(value):
-    """
+    '''
     A slightly better title template filter.
 
     Same as Django's builtin `~django.template.defaultfilters.title` filter,
     but operates on individual words and leaves words unchanged if they already
-    have a capital letter.
-    """
-    title_word = lambda w: w if RE_UPPERCASE.search(w) else old_title(w)
-    return re.sub('(\S+)', lambda m: title_word(m.group(0)), value)
+    have a capital letter or a digit. Actually Django's filter also skips
+    words with digits but only for latin letters (or at least not for
+    cyrillic ones).
+    '''
+    return ' '.join([
+        any([c.isupper() or c.isdigit() for c in w]) and w or old_title(w)
+        for w in value.split()
+    ])
+
+
 title.is_safe = True
 
+try:
+    from django.utils.functional import keep_lazy_text
+    title = keep_lazy_text(title)
+except ImportError:
+    # to keep backward (Django < 1.10) compatibility
+    from django.utils.functional import lazy
+    title = lazy(title, six.text_type)
+
 register.filter('localize', l10n_register.filters['localize'])
 register.filter('unlocalize', l10n_register.filters['unlocalize'])
