@@ -5,10 +5,11 @@ from django.shortcuts import render
 from django.utils.lorem_ipsum import words
 from django.views.generic.base import TemplateView
 
-from django_filters.views import FilterView
-from django_tables2 import MultiTableMixin, RequestConfig, SingleTableView
+from django_filters.views import FilterMixin, FilterView
+from django_tables2 import MultiTableMixin, RequestConfig, SingleTableMixin, SingleTableView
 from django_tables2.export.views import ExportMixin
 
+from .data import COUNTRIES
 from .filters import PersonFilter
 from .models import Country, Person
 from .tables import BootstrapTable, CountryTable, PersonTable, SemanticTable, ThemedCountryTable
@@ -22,6 +23,11 @@ except ImportError:
 
 def create_fake_data():
     # create some fake data to make sure we need to paginate
+    if Country.objects.all().count() < 50:
+        for country in COUNTRIES.splitlines():
+            name, population = country.split(';')
+            Country.objects.create(name=name, visits=0, population=int(population))
+
     if Person.objects.all().count() < 50:
         countries = list(Country.objects.all()) + [None]
         Person.objects.bulk_create([
@@ -130,7 +136,7 @@ def tutorial(request):
     return render(request, 'tutorial.html', {'people': Person.objects.all()})
 
 
-class FilteredPersonListView(FilterView, ExportMixin, SingleTableView):
+class FilteredPersonListView(SingleTableMixin, FilterView):
     table_class = PersonTable
     model = Person
     template_name = 'bootstrap_template.html'
