@@ -2,6 +2,7 @@
 from __future__ import unicode_literals
 
 import pytest
+from django.db import models
 from django.utils.safestring import SafeData, mark_safe
 from django.utils.translation import ugettext_lazy
 
@@ -157,10 +158,10 @@ def test_supports_is_ordered():
 
 
 def test_translation():
-    """
+    '''
     Tests different types of values for the ``verbose_name`` property of a
     column.
-    """
+    '''
     class TranslationTable(tables.Table):
         text = tables.Column(verbose_name=ugettext_lazy('Text'))
 
@@ -169,9 +170,9 @@ def test_translation():
 
 
 def test_sequence():
-    """
+    '''
     Ensures that the sequence of columns is configurable.
-    """
+    '''
     class TestTable(tables.Table):
         a = tables.Column()
         b = tables.Column()
@@ -234,11 +235,11 @@ def test_sequence():
 
 
 def test_should_support_both_meta_sequence_and_constructor_exclude():
-    """
+    '''
     Issue #32 describes a problem when both ``Meta.sequence`` and
     ``Table(..., exclude=...)`` are used on a single table. The bug caused an
     exception to be raised when the table was iterated.
-    """
+    '''
     class SequencedTable(tables.Table):
         a = tables.Column()
         b = tables.Column()
@@ -335,3 +336,108 @@ def test_raises_when_using_non_supported_index():
     row = table.rows[0]
     with pytest.raises(TypeError):
         row[table]
+
+
+class MyModel(models.Model):
+    item1 = models.CharField(max_length=10)
+
+    class Meta:
+        app_label = 'django_tables2_tests'
+
+
+class MyTable(tables.Table):
+    item1 = tables.Column(verbose_name='Nice column name')
+
+    class Meta:
+        model = MyModel
+        fields = ('item1', )
+
+
+def test_column_params_should_be_preserved_under_inheritance():
+    '''
+    Github issue #337
+
+    Columns explicitly defined on MyTable get overridden by columns implicitly
+    defined on it's child.
+    If the column is not redefined, the explicit definition of MyTable is used,
+    preserving the specialized verbose_name defined on it.
+    '''
+
+    class MyTableA(MyTable):
+        '''
+        having an empty `class Meta` should not undo the explicit definition
+        of column item1 in MyTable.
+        '''
+        class Meta(MyTable.Meta):
+            pass
+
+    class MyTableB(MyTable):
+        '''
+        having a non-empty `class Meta` should not undo the explicit definition
+        of column item1 in MyTable.
+        '''
+        class Meta(MyTable.Meta):
+            per_page = 22
+
+    table = MyTable(MyModel.objects.all())
+    tableA = MyTableA(MyModel.objects.all())
+    tableB = MyTableB(MyModel.objects.all())
+
+    assert table.columns['item1'].verbose_name == 'Nice column name'
+    assert tableA.columns['item1'].verbose_name == 'Nice column name'
+    assert tableB.columns['item1'].verbose_name == 'Nice column name'
+
+
+def test_explicit_column_can_be_overridden_by_other_explicit_column():
+    class MyTableC(MyTable):
+        '''
+        If we define a new explict item1 column, that one should be used.
+        '''
+        item1 = tables.Column(verbose_name='New nice column name')
+
+    table = MyTable(MyModel.objects.all())
+    tableC = MyTableC(MyModel.objects.all())
+
+    assert table.columns['item1'].verbose_name == 'Nice column name'
+    assert tableC.columns['item1'].verbose_name == 'New nice column name'
+
+
+def test_override_column_class_names():
+    '''
+    We control the output of CSS class names for a column by overriding
+    get_column_class_names
+    '''
+    class MyTable(tables.Table):
+        population = tables.Column(verbose_name='Population')
+
+        def get_column_class_names(self, classes_set, bound_column):
+            classes_set.add('prefix-%s' % bound_column.name)
+            return classes_set
+
+    TEST_DATA = [
+        {'name': 'Belgium', 'population': 11200000},
+        {'name': 'Luxembourgh', 'population': 540000},
+        {'name': 'France', 'population': 66000000},
+    ]
+
+    html = MyTable(TEST_DATA).as_html(build_request())
+
+    assert '<td class="prefix-population">11200000</td>' in html
+
+
+@pytest.mark.django_db
+def test_computable_td_attrs():
+    '''Computable attrs for columns, using table argument'''
+    Person.objects.create(first_name='Jan', last_name='Pietersz.')
+    Person.objects.create(first_name='Sjon', last_name='Jansen')
+
+    class Table(tables.Table):
+        person = tables.Column(attrs={
+            'cell': {
+                'data-length': lambda table: len(table.data)
+            }
+        })
+
+    table = Table(Person.objects.all())
+    html = table.as_html(request)
+    assert 'data-length="2"' in html
