@@ -2,7 +2,6 @@
 from __future__ import unicode_literals
 
 import pytest
-from django.core.urlresolvers import reverse
 from django.template import Context, Template
 from django.utils.html import mark_safe
 
@@ -12,10 +11,15 @@ from django_tables2 import A
 from ..app.models import Occupation, Person
 from ..utils import attrs, build_request
 
+try:
+    from django.urls import reverse
+except ImportError:
+    # to keep backward (Django <= 1.9) compatibility
+    from django.core.urlresolvers import reverse
+
 
 def test_unicode():
-    """Test LinkColumn"""
-    # test unicode values + headings
+    '''Test LinkColumn for unicode values + headings'''
     class UnicodeTable(tables.Table):
         first_name = tables.LinkColumn('person', args=[A('pk')])
         last_name = tables.LinkColumn('person', args=[A('pk')], verbose_name='äÚ¨´ˆÁ˜¨ˆ˜˘Ú…Ò˚ˆπ∆ˆ´')
@@ -25,10 +29,11 @@ def test_unicode():
         {'pk': 2, 'first_name': 'Chr…s', 'last_name': 'DÒble'},
     ]
 
-    table = UnicodeTable(dataset)
-    request = build_request('/some-url/')
     template = Template('{% load django_tables2 %}{% render_table table %}')
-    html = template.render(Context({'request': request, 'table': table}))
+    html = template.render(Context({
+        'request': build_request(),
+        'table': UnicodeTable(dataset)
+    }))
 
     assert 'Brädley' in html
     assert '∆yers' in html
@@ -49,8 +54,7 @@ def test_link_text_custom_value():
         {'pk': 1, 'first_name': 'John', 'last_name': 'Doe'}
     ]
 
-    table = CustomLinkTable(dataset)
-    html = table.as_html(build_request('/some-url/'))
+    html = CustomLinkTable(dataset).as_html(build_request())
 
     assert 'foo::bar' in html
     assert 'Doe John' in html
@@ -68,8 +72,7 @@ def test_link_text_escaping():
         {'pk': 1, 'first_name': 'John', 'last_name': 'Doe'}
     ]
 
-    table = CustomLinkTable(dataset)
-    html = table.as_html(build_request('/some-url/'))
+    html = CustomLinkTable(dataset).as_html(build_request())
 
     expected = '<td class="editlink"><a href="{}">edit</a></td>'.format(
         reverse('person', args=(1, ))
@@ -113,10 +116,10 @@ def test_kwargs():
     class PersonTable(tables.Table):
         a = tables.LinkColumn('occupation', kwargs={'pk': A('a')})
 
-    request = build_request('/')
-    html = PersonTable([{'a': 0}, {'a': 1}]).as_html(request)
-    assert reverse('occupation', kwargs={'pk': 0}) in html
-    assert reverse('occupation', kwargs={'pk': 1}) in html
+    table = PersonTable([{'a': 0}, {'a': 1}])
+
+    assert reverse('occupation', kwargs={'pk': 0}) in table.rows[0].get_cell('a')
+    assert reverse('occupation', kwargs={'pk': 1}) in table.rows[1].get_cell('a')
 
 
 def test_html_escape_value():
@@ -139,6 +142,34 @@ def test_a_attrs_should_be_supported():
     }
 
 
+@pytest.mark.django_db
+def test_td_attrs_should_be_supported():
+    '''LinkColumn should support both <td> and <a> attrs'''
+
+    person = Person.objects.create(first_name='Bob', last_name='Builder')
+
+    class Table(tables.Table):
+        first_name = tables.LinkColumn(attrs={
+            'a': {'style': 'color: red;'},
+            'td': {'style': 'background-color: #ddd;'}
+        })
+        last_name = tables.Column()
+
+    table = Table(Person.objects.all())
+
+    a_tag = table.rows[0].get_cell('first_name')
+    assert 'href="{}"'.format(reverse('person', args=(person.pk, ))) in a_tag
+    assert 'style="color: red;"' in a_tag
+    assert person.first_name in a_tag
+
+    html = table.as_html(build_request())
+
+    td_tag_1 = '<td style="background-color: #ddd;" class="first_name">'
+    td_tag_2 = '<td class="first_name" style="background-color: #ddd;">'
+
+    assert td_tag_1 in html or td_tag_2 in html
+
+
 def test_defaults():
     class Table(tables.Table):
         link = tables.LinkColumn('occupation', kwargs={'pk': 1}, default='xyz')
@@ -156,11 +187,18 @@ def test_get_absolute_url():
     person = Person.objects.create(first_name='Jan Pieter', last_name='Waagmeester', )
     table = PersonTable(Person.objects.all())
 
-    expected = '<a href="/people/%d/">Waagmeester</a>' % person.pk
+    expected = '<a href="{}">{}</a>'.format(
+        reverse('person', args=(person.pk, )),
+        person.last_name
+    )
     assert table.rows[0].get_cell('last_name') == expected
 
 
 def test_get_absolute_url_not_defined():
+    '''
+    The dict doesn't have a get_absolute_url(), so creating the table should
+    raise a TypeError
+    '''
     class Table(tables.Table):
         first_name = tables.Column()
         last_name = tables.LinkColumn()
@@ -170,7 +208,7 @@ def test_get_absolute_url_not_defined():
     ])
 
     with pytest.raises(TypeError):
-        table.as_html(build_request('/'))
+        table.as_html(build_request())
 
 
 @pytest.mark.django_db
@@ -186,3 +224,11 @@ def test_RelatedLinkColumn():
     table = Table(Person.objects.all())
 
     assert table.rows[0].get_cell('occupation') == '<a href="/occupations/%d/">Carpenter</a>' % carpenter.pk
+
+
+def test_value_returns_a_raw_value_without_html():
+    class Table(tables.Table):
+        col = tables.LinkColumn('occupation', args=(A('id'), ))
+
+    table = Table([{'col': 'link-text', 'id': 1}])
+    assert table.rows[0].get_cell_value('col') == 'link-text'
