@@ -8,7 +8,9 @@ from django.db import models
 import django_tables2 as tables
 
 
-# Format string: https://docs.djangoproject.com/en/stable/ref/templates/builtins/#date
+'''
+Format string: https://docs.djangoproject.com/en/stable/ref/templates/builtins/#date
+'''
 
 
 def test_should_handle_explicit_format():
@@ -36,3 +38,11 @@ def test_should_be_used_for_timefields():
             model = TimeModel
 
     assert type(Table.base_columns['field']) == tables.TimeColumn
+
+
+def test_value_returns_a_raw_value_without_html():
+    class Table(tables.Table):
+        col = tables.TimeColumn(format='H:i:s')
+
+    table = Table([{'col': time(11, 11, 11)}])
+    assert table.rows[0].get_cell_value('col') == '11:11:11'
