@@ -1,19 +1,29 @@
 # coding: utf-8
 from __future__ import unicode_literals
 
+import pytest
 from django.template import Context, Template
 from django.test import TransactionTestCase
 from django.utils.translation import override as translation_override
 from django.utils.translation import ugettext_lazy
 
 import django_tables2 as tables
-import pytest
 from django_tables2.config import RequestConfig
 
 from .app.models import Person
 from .utils import build_request, parse
 
 
+def test_template_override_in_settings(settings):
+    settings.DJANGO_TABLES2_TEMPLATE = 'foo/bar.html'
+
+    class Table(tables.Table):
+        column = tables.Column()
+
+    table = Table({})
+    assert table.template == 'foo/bar.html'
+
+
 class CountryTable(tables.Table):
     name = tables.Column()
     capital = tables.Column(orderable=False,
@@ -75,7 +85,7 @@ def test_as_html():
 
 
 def test_custom_rendering():
-    """For good measure, render some actual templates."""
+    '''For good measure, render some actual templates.'''
     countries = CountryTable(MEMORY_DATA)
     context = Context({'countries': countries})
 
@@ -254,17 +264,21 @@ def test_localization_of_pagination_string():
     with translation_override('it'):
         assert 'Pagina 1 di 4' in table.as_html(request)
 
+    with translation_override('nb'):
+        assert 'Side 1 av 4' in table.as_html(request)
+
 
 class BootstrapTable(CountryTable):
     class Meta:
         template = 'django_tables2/bootstrap.html'
         prefix = 'bootstrap-'
+        per_page = 2
 
 
 def test_boostrap_template():
     table = BootstrapTable(MEMORY_DATA)
     request = build_request('/')
-    RequestConfig(request, {'per_page': 2}).configure(table)
+    RequestConfig(request).configure(table)
 
     template = Template('{% load django_tables2 %}{% render_table table %}')
     html = template.render(Context({'request': request, 'table': table}))
@@ -274,6 +288,54 @@ def test_boostrap_template():
     assert len(root.findall('.//tbody/tr')) == 2
     assert len(root.findall('.//tbody/tr/td')) == 8
 
-    assert root.find('ul[@class="pager"]/li[@class="cardinality"]').text.strip() == 'Page 1 of 2'
+    assert root.find('./ul[@class="pager list-inline"]/li[@class="cardinality"]/small').text.strip() == 'Page 1 of 2'
     # make sure the link is prefixed
-    assert root.find('ul[@class="pager"]/li[@class="next"]/a').get('href') == '?bootstrap-page=2'
+    assert root.find('./ul[@class="pager list-inline"]/li[@class="next"]/a').get('href') == '?bootstrap-page=2'
+
+
+class SemanticTable(CountryTable):
+    class Meta:
+        template = 'django_tables2/semantic.html'
+        prefix = 'semantic-'
+        per_page = 2
+
+
+def test_semantic_template():
+    table = SemanticTable(MEMORY_DATA)
+    request = build_request('/')
+    RequestConfig(request).configure(table)
+
+    template = Template('{% load django_tables2 %}{% render_table table %}')
+    html = template.render(Context({'request': request, 'table': table}))
+    root = parse(html)
+    assert len(root.findall('.//thead/tr')) == 1
+    assert len(root.findall('.//thead/tr/th')) == 4
+    assert len(root.findall('.//tbody/tr')) == 2
+    assert len(root.findall('.//tbody/tr/td')) == 8
+
+    pager = './/tfoot/tr/th/div[@class="ui right floated pagination menu"]/div[@class="item"]'
+    assert root.find(pager).text.strip() == 'Page 1 of 2'
+    # make sure the link is prefixed
+    next_page = './/tfoot/tr/th/div[@class="ui right floated pagination menu"]/a[@class="icon item"]'
+    assert root.find(next_page).get('href') == '?semantic-page=2'
+
+
+def test_bootstrap_responsive_template():
+    class BootstrapResponsiveTable(BootstrapTable):
+        class Meta(BootstrapTable.Meta):
+            template = 'django_tables2/bootstrap-responsive.html'
+
+    table = BootstrapResponsiveTable(MEMORY_DATA)
+    request = build_request('/')
+    RequestConfig(request).configure(table)
+
+    template = Template('{% load django_tables2 %}{% render_table table %}')
+    html = template.render(Context({'request': request, 'table': table}))
+    root = parse(html)
+    assert len(root.findall('.//thead/tr')) == 1
+    assert len(root.findall('.//thead/tr/th')) == 4
+    assert len(root.findall('.//tbody/tr')) == 2
+    assert len(root.findall('.//tbody/tr/td')) == 8
+
+    pager = './/ul/li[@class="cardinality"]/small'
+    assert root.find(pager).text.strip() == 'Page 1 of 2'
