@@ -1,11 +1,10 @@
 # coding: utf-8
+import pytest
 from django.db import models
 from django.utils import six
 
-import pytest
-from django_tables2.utils import (Accessor, AttributeDict, OrderBy,
-                                  OrderByTuple, Sequence, computed_values,
-                                  segment, signature)
+from django_tables2.utils import (Accessor, AttributeDict, OrderBy, OrderByTuple, Sequence, call_with_appropriate,
+                                  computed_values, segment, signature)
 
 
 def test_orderbytuple():
@@ -177,7 +176,7 @@ def test_computed_values_with_argument():
         'foo': lambda y: {
             'bar': lambda y: 'baz-{}'.format(y)
         }
-    }, y=2)
+    }, kwargs=dict(y=2))
     assert x == {'foo': {'bar': 'baz-2'}}
 
 
@@ -240,3 +239,19 @@ def test_signature_catch_all_kwargs():
     args, keywords = signature(foo)
     assert args == ('bar', 'baz')
     assert keywords == 'kwargs'
+
+
+def test_call_with_appropriate():
+
+    def foo():
+        return 'bar'
+
+    assert call_with_appropriate(foo, {
+        'a': 'd',
+        'c': 'e'
+    }) == 'bar'
+
+    def bar(baz):
+        return baz
+
+    assert call_with_appropriate(bar, dict(baz=23)) == 23
